@@ -74,6 +74,8 @@ indicator_display (gpointer indicator, guint timestamp, const gchar *channel)
                 g_debug ("INDICATOR: Changing to channel %s", channel);
 		win = (GtkWindow *)xchat_get_info (ph, "win_ptr");
 		if (xchat_set_context (ph, ctx)) {
+			g_debug ("INDICATOR: Showing window");
+			xchat_command (ph, "GUI SHOW"); 
 			xchat_command (ph, "GUI FOCUS"); 
 			gtk_widget_show (GTK_WIDGET (win));
 			really_activate_window (GTK_WINDOW (win));
@@ -94,6 +96,7 @@ server_display (IndicateServer * indicate_server, guint timestamp, gpointer data
 {
 	GtkWindow *win = (GtkWindow *)xchat_get_info (ph, "win_ptr");
         really_activate_window (GTK_WINDOW (win));
+	xchat_command (ph, "GUI SHOW"); 
 	/* gtk_window_present_with_time(GTK_WINDOW (win), timestamp); */
 	g_debug ("INDICATOR: Showing the window");
         /* XXX: Should clear all indicators */
@@ -239,7 +242,7 @@ indicate_msg_cb (char *word[], gpointer data)
         const gchar *channel = xchat_get_info (ph, "channel");
         win = (GtkWindow *)xchat_get_info (ph, "win_ptr");
 
-	if (focused == channel && gtk_window_is_active (GTK_WINDOW (win)))
+	if (focused == channel && GTK_WINDOW (win)->has_toplevel_focus)
 		return XCHAT_EAT_NONE;
 
 	g_debug ("INDICATOR: channel %s is not focused, adding indicator", channel);
@@ -266,7 +269,7 @@ focus_tab_cb (char *word[], gpointer data)
 gboolean
 focus_win_cb (GtkWindow *win,  GParamSpec *pspec, gpointer data)
 {
-	if (!gtk_window_is_active (GTK_WINDOW (win)))
+	if (!GTK_WINDOW (win)->has_toplevel_focus)
 	{
 		return FALSE;
 	}
